@@ -1,5 +1,5 @@
 """
-'subtypes' is too of a common package name, avoid clashes
+'subtypes' is too much of a common package name, avoid clashes
 """
 from pkgutil import extend_path
 
